==> haskell-mutable-containers-0.3.4.1-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mutable-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mutable-containers
version:              0.3.4.1
visibility:           public
id:                   mutable-containers-0.3.4.1-7UVS0LHWOle5G8rxT5OR8W
key:                  mutable-containers-0.3.4.1-7UVS0LHWOle5G8rxT5OR8W
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Abstactions and concrete implementations of mutable containers

description:
    See docs and README at <http://www.stackage.org/package/mutable-containers>

category:             Data
abi:                  3eff9345dc646456f2b95e88b5947165
exposed:              True
exposed-modules:      Data.Mutable
hidden-modules:
    Data.Mutable.BRef Data.Mutable.Class Data.Mutable.Deque
    Data.Mutable.DLList Data.Mutable.PRef Data.Mutable.SRef
    Data.Mutable.URef Paths_mutable_containers

import-dirs:          /usr/lib/ghc-9.0.2/site-local/mutable-containers-0.3.4.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/mutable-containers-0.3.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mutable-containers
hs-libraries:         HSmutable-containers-0.3.4.1-7UVS0LHWOle5G8rxT5OR8W
depends:
    base-4.15.1.0 containers-0.6.4.1 ghc-prim-0.7.0
    mono-traversable-1.0.15.3-69BMaYtPZQj2zXF5081736
    primitive-0.7.4.0-9TVgKpsxQ9UKsTlz0zg7yv
    vector-0.13.0.0-C4IY0qsV06C5Tx1gtETdzw

haddock-interfaces:
    /usr/share/doc/haskell-mutable-containers/html/mutable-containers.haddock

haddock-html:         /usr/share/doc/haskell-mutable-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mutable-containers-0.3.4.1-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mutable-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mutable-containers
version:              0.3.4.1
visibility:           public
id:                   mutable-containers-0.3.4.1-5Vlr3puDSBcI4jb7T7Gqj1
key:                  mutable-containers-0.3.4.1-5Vlr3puDSBcI4jb7T7Gqj1
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Abstactions and concrete implementations of mutable containers

description:
    See docs and README at <http://www.stackage.org/package/mutable-containers>

category:             Data
abi:                  4586414293f51a1830ef52d585d5768a
exposed:              True
exposed-modules:      Data.Mutable
hidden-modules:
    Data.Mutable.BRef Data.Mutable.Class Data.Mutable.Deque
    Data.Mutable.DLList Data.Mutable.PRef Data.Mutable.SRef
    Data.Mutable.URef Paths_mutable_containers

import-dirs:          /usr/lib/ghc-9.0.2/site-local/mutable-containers-0.3.4.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/mutable-containers-0.3.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mutable-containers
hs-libraries:         HSmutable-containers-0.3.4.1-5Vlr3puDSBcI4jb7T7Gqj1
depends:
    base-4.15.1.0 containers-0.6.4.1 ghc-prim-0.7.0
    mono-traversable-1.0.15.3-Fn6JfetnmXn9EEanVeLXcp
    primitive-0.7.4.0-9TVgKpsxQ9UKsTlz0zg7yv
    vector-0.13.0.0-C4IY0qsV06C5Tx1gtETdzw

haddock-interfaces:
    /usr/share/doc/haskell-mutable-containers/html/mutable-containers.haddock

haddock-html:         /usr/share/doc/haskell-mutable-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
